==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebForOfDataChangingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebForOfDataChangingEventArgsDetailDescription } from "./WebForOfDataChangingEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebForOfDataChangingEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebForOfDataChangingEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebForOfDataChangingEventArgsDetailDescriptionMetadata.a == null) {
                WebForOfDataChangingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebForOfDataChangingEventArgsDetailDescriptionMetadata.c(WebForOfDataChangingEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebForOfDataChangingEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebForOfDataChangingEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ForOfDataChangingEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("ContainerSize", "Number:double");
        }
        static d(a) {
            WebForOfDataChangingEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebForOfDataChangingEventArgsDetail", () => new WebForOfDataChangingEventArgsDetailDescription());
            a.ac("WebForOfDataChangingEventArgsDetail", WebForOfDataChangingEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.$t = markType(WebForOfDataChangingEventArgsDetailDescriptionMetadata, 'WebForOfDataChangingEventArgsDetailDescriptionMetadata');
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.a = null;
    return WebForOfDataChangingEventArgsDetailDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebForOfDataChangingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfStateDescriptionMetadata } from "./WebForOfStateDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebForOfDataChangingEventArgsDetailDescription } from "./WebForOfDataChangingEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebForOfDataChangingEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebForOfDataChangingEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebForOfDataChangingEventArgsDetailDescriptionMetadata.a == null) {
                WebForOfDataChangingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebForOfDataChangingEventArgsDetailDescriptionMetadata.c(WebForOfDataChangingEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebForOfDataChangingEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebForOfDataChangingEventArgsDetailDescriptionMetadata.a);
            WebForOfStateDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ForOfDataChangingEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("ContainerSize", "Number:double");
            a.item("State", "ExportedType:WebForOfState");
        }
        static d(a) {
            WebForOfDataChangingEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebForOfDataChangingEventArgsDetail", () => new WebForOfDataChangingEventArgsDetailDescription());
            a.ad("WebForOfDataChangingEventArgsDetail", WebForOfDataChangingEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.$t = markType(WebForOfDataChangingEventArgsDetailDescriptionMetadata, 'WebForOfDataChangingEventArgsDetailDescriptionMetadata');
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.a = null;
    return WebForOfDataChangingEventArgsDetailDescriptionMetadata;
})();
